==> react-html-replace-0.0.5.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from 'react';

var extractPropsFromString = function extractPropsFromString(attr) {
  var propsStr = attr.match(/\s*([\w]*)\s*=\s*"([\w]*)"/gi) || [];
  return Object.assign.apply(Object, [{}].concat(propsStr.map(function (s) {
    var _ref;

    var arr = s.split('=');
    return _ref = {}, _ref[(arr[0] || '').trim()] = (arr[1] || '').replace(/\s*["]+/g, ''), _ref;
  }).flat()));
};

/**
 * 
 * const fn = (tag, props) => {
    if (tag === 'mention') {
      return <MentionBlock />;
    }
    if (tag === 'bold') {
      return <b />;
    }
    if (tag === 'italic') {
      return <i />;
    }
  }
 */

var parseText = function parseText() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var fn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};

  var tags = [];
  var jsxElements = [];
  var prevIndex = -1;
  var matches = text.matchAll(/<\s*(\/\s*)*([^>\s]*)[^><]*>/gi);

  for (var _iterator = matches, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref2;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref2 = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref2 = _i.value;
    }

    var match = _ref2;
    var substring = match[0],
        isClosing = match[1],
        tag = match[2];

    var index = match['index'];
    tag = (tag || '').trim();
    isClosing = (isClosing || '').trim();
    substring = (substring || '').trim();
    if (!isClosing) {
      if (tags.length === 0) {
        if (index > prevIndex) {
          jsxElements.push(text.slice(prevIndex + 1, index));
        }
      }
      tags.push({ tag: tag, substring: substring, index: index });
    } else if (isClosing && tags.length > 0 && tag === tags[tags.length - 1].tag) {
      var tagObj = tags.pop();
      if (tags.length === 0) {
        var _substring = tagObj.substring,
            _tag = tagObj.tag;

        var attr = _substring.replace(/[<>]/gi, '').replace(_tag, '');
        var props = extractPropsFromString(attr);
        var innertext = text.slice(text.indexOf('>', tagObj.index) + 1, index);
        var JsxEl = fn(_tag, _extends({}, props, { innertext: innertext }));

        var el = null;
        if (JsxEl) {
          el = React.cloneElement(JsxEl, {}, parseText(innertext, fn));
        } else {
          el = _substring + ' innertext </' + _tag + '>';
        }
        jsxElements.push(el);
        prevIndex = text.indexOf('>', index);
      }
    } else {
      throw Error('Invalid string, no matching tag "' + tag + '"');
    }
  }
  if (tags.length !== 0) {
    throw Error('Invalid string, no matching tags : "' + (tags.map(function (t) {
      return t.tag;
    }) || '').toString() + '"');
  }
  if (text.length - 1 > prevIndex) {
    jsxElements.push(text.slice(prevIndex + 1));
  }
  return jsxElements;
};

export default parseText;

==> react-html-replace-0.0.7.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from 'react';

var extractPropsFromString = function extractPropsFromString(attr) {
  var propsStr = attr.match(/\s*([^=]*)\s*=\s*"([^"]*)"/gi) || [];
  return Object.assign.apply(Object, [{}].concat(propsStr.map(function (s) {
    var _ref;

    var arr = s.split('=');
    return _ref = {}, _ref[(arr[0] || '').trim()] = (arr[1] || '').replace(/\s*["]+/g, ''), _ref;
  }).flat()));
};

/**
 * 
 * const fn = (tag, props) => {
    if (tag === 'mention') {
      return <MentionBlock />;
    }
    if (tag === 'bold') {
      return <b />;
    }
    if (tag === 'italic') {
      return <i />;
    }
  }
 */

var parseText = function parseText() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var fn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};

  var tags = [];
  var jsxElements = [];
  var prevIndex = -1;
  var matches = text.matchAll(/<\s*(\/\s*)*([^>\s]*)[^><]*>/gi);

  for (var _iterator = matches, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref2;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref2 = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref2 = _i.value;
    }

    var match = _ref2;
    var substring = match[0],
        isClosing = match[1],
        tag = match[2];

    var index = match['index'];
    tag = (tag || '').trim();
    isClosing = (isClosing || '').trim();
    substring = (substring || '').trim();
    if (!isClosing) {
      if (tags.length === 0) {
        if (index > prevIndex) {
          jsxElements.push(text.slice(prevIndex + 1, index));
        }
      }
      tags.push({ tag: tag, substring: substring, index: index });
    } else if (isClosing && tags.length > 0 && tag === tags[tags.length - 1].tag) {
      var tagObj = tags.pop();
      if (tags.length === 0) {
        (function () {
          var substring = tagObj.substring,
              tag = tagObj.tag;

          var attr = substring.replace(/[<>]/gi, '').replace(tag, '');
          var props = extractPropsFromString(attr);
          var innertext = text.slice(text.indexOf('>', tagObj.index) + 1, index);
          var JsxEl = fn(tag, _extends({}, props, { innertext: innertext }));

          var cloneElement = function cloneElement(el) {
            if (el.props && el.props.children) {
              return React.cloneElement(el, {}, cloneElement(el.props.children));
            } else if (el.props) {
              return React.cloneElement(el, {}, parseText(innertext, fn));
            } else {
              return [el, parseText(innertext, fn)];
            }
          };

          var el = null;
          if (JsxEl) {
            el = cloneElement(JsxEl);
          } else {
            el = substring + ' innertext </' + tag + '>';
          }
          jsxElements.push(el);
          prevIndex = text.indexOf('>', index);
        })();
      }
    } else {
      throw Error('Invalid string, no matching tag "' + tag + '"');
    }
  }
  if (tags.length !== 0) {
    throw Error('Invalid string, no matching tags : "' + (tags.map(function (t) {
      return t.tag;
    }) || '').toString() + '"');
  }
  if (text.length - 1 > prevIndex) {
    jsxElements.push(text.slice(prevIndex + 1));
  }
  return jsxElements;
};

export default parseText;
